@@ -1,5 +1,5 @@
 from mongoengine import *
-
+from cryptomodel.operations import OPERATIONS
 
 class EUR(EmbeddedDocument):
     meta = {'strict': False}
@@ -27,13 +27,14 @@ class Coin(EmbeddedDocument):
 
 class Status(EmbeddedDocument):
     meta = {'strict': False}
-    timestamp = StringField()
+    timestamp = IntField()
 
 
 class prices(Document):
     meta = {'strict': False}
     _id = IntField(db_field='_id')
     coins = EmbeddedDocumentListField(Coin, db_field='data')
-    status = ListField(EmbeddedDocumentListField(Status, db_field='status'))
-
+    status = EmbeddedDocumentField(Status, db_field='status')
+    source_id = ObjectIdField()
+    operation = StringField(choices=OPERATIONS.choices())
 
